####################
Line Measurer (LiMe)
####################

This library provides a set of tools to fit emission lines from ionized spectra. Its data pipeline aims for a simple and
personalised analysis of both single line and Big Data observations. The data labeling and storage has been designed to
meet the requirements of the chemical and kinematic analysis of astronomical nebulae.

Getting Started
===============

The current beta version has been developed for the ULS students and researchers.

Installation
============

The library can be installed directly from its pip_ project page. To get the current version type:

``pip install lime-stable``

The current version of LiMe has the following dependencies (please check their documentation if you need to install them):

* Numpy
* LmFit
* Pandas
* Matplotlib

The following libraries are not necessary but they provide a richer experience on the library inputs and outputs:

* Astropy
* PyNeb
* PyLatex
* Specutils

Development
===========

LiMe is currently in a beta realese. Please check its github_ for the latest version news and tutorials.
Any comment/issue/request can be added as an issue on its github_ page.


.. _pip: https://pypi.org/project/lime-stable/
.. _github: https://github.com/Vital-Fernandez/lime

